
Analysis
========

A package of the classes for analysing molecules in :mod:`.CGExplore`.

.. toctree::
  :maxdepth: 1

  Analysis module <_autosummary/cgexplore.analysis>

Geometry
--------

To analyse the geometry of CG molecules (including size and pore metrics),
see:

.. toctree::
  :maxdepth: 1

  GeomMeasure <_autosummary/cgexplore.analysis.GeomMeasure>

Shape
-----

We have a series of functions (moving into one class
:class:`cgexplore.analysing.ShapeMeasure`) for interfacing with
`Shape <https://www.iqtc.ub.edu/uncategorised/program-for-the-stereochemical-analysis-of-molecular-fragments-by-means-of-continous-shape-measures-and-associated-tools/>`_.
I recommend using what is in this class:

.. toctree::
  :maxdepth: 1

  ShapeMeasure <_autosummary/cgexplore.analysis.ShapeMeasure>

Utility functions:

.. toctree::
  :maxdepth: 1

  known_shape_vectors <_autosummary/cgexplore.analysis.known_shape_vectors>


